CircLink
========

.. image:: https://img.shields.io/readthedocs/circlink/latest
   :target: https://circlink.readthedocs.io/en/latest/
   :alt: Read the Docs (latest)

.. image:: https://img.shields.io/github/actions/workflow/status/tekktrik/circlink/build.yml?branch=main
   :target:  https://github.com/tekktrik/circlink/actions
   :alt: Build CI status (main branch)

.. image:: https://img.shields.io/pypi/pyversions/circlink
   :target: https://pypi.org/project/circlink/
   :alt: PyPI - Python Versions

.. image:: https://img.shields.io/pypi/v/circlink
   :target: https://pypi.org/project/circlink/
   :alt: Latest PyPI Release

.. image:: https://img.shields.io/github/license/tekktrik/circlink
   :target: https://github.com/tekktrik/circlink/blob/main/LICENSE
   :alt: MIT License

.. image:: https://img.shields.io/badge/maintained-yes-green
   :target: https://github.com/tekktrik/circlink/issues
   :alt: Maintenaned

.. image:: https://raw.githubusercontent.com/adafruit/Adafruit_CircuitPython_Bundle/main/badges/adafruit_discord.svg
    :target: https://adafru.it/discord
    :alt: Adafruit Discord

Write code locally and have it automatically pushed to your CircuitPython device

Documentation
=============

Documentation for ``circlink`` can be found `on ReadTheDocs <https://circlink.readthedocs.io/en/latest/>`_.

License
=======

This library is licensed under an MIT license, so feel free to do with it what
you want, and contributions are always welcome!
